==> superior6564-0.0.9.tar.gz: superior6564-0.0.9/setup.py <==
#!/usr/bin/env python

from io import open
from setuptools import setup


"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


with open('superior6564/info.txt') as f:
    sum_letters = ""
    version = []
    while sum_letters != "Version":
        line = f.readline()
        if len(line) >= 7:
            sum_letters = ""
            for i in range(7):
                sum_letters += line[i]
                if sum_letters == "Version":
                    for j in range(5):
                        version.append(line[j + 22])

version = version[0] + version[1] + version[2] + version[3] + version[4]

with open('superior6564/info.txt') as f:
    install_description = f.read()

with open('README.md', "w", encoding='utf-8') as f:
    f.write(install_description)

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='superior6564',
    version=version,

    author='Superior_6564',
    author_email='vip.klochayil@gmail.com',

    description=(
        u'Python library which maybe will help to people.  '
        u'Before using you need to run packages.required()'
    ),
    long_description=long_description,
    # long_description_content_type='text/markdown',

    url='https://github.com/Superior-GitHub/Superior6564',
    download_url='https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip'.format(
        version
    ),

    license='Apache License, Version 2.0, see LICENSE file',

    packages=['superior6564'],
    install_requires=['', ''],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ]
)

==> superior6564-0.1.0.tar.gz: superior6564-0.1.0/setup.py <==
#!/usr/bin/env python

from io import open
from setuptools import setup
import requests


"""
:authors: Superior_6564
:license: Apache License, Version 2.0, see LICENSE file
:copyright: (c) 2022 Superior_6564
"""


version = '0.1.0'

__version__ = version

with open('README.md') as f:
    f.readline()
    test_description = f.read()

with open('README.md', "w") as f:
    install_description = "Version of package is " + version + "\n\n" + test_description
    f.write(install_description)

with open('README.md', encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='superior6564',
    version=version,

    author='Superior_6564',
    author_email='vip.klochayil@gmail.com',

    description=(
        u'Python library which maybe will help to people.  '
        u'Before using you need to run packages.required()'
    ),
    long_description=long_description,
    # long_description_content_type='text/markdown',

    url='https://github.com/Superior-GitHub/Superior6564',
    download_url='https://github.com/Superior-GitHub/Superior6564/archive/refs/heads/main.zip'.format(
        version
    ),

    license='Apache License, Version 2.0, see LICENSE file',

    packages=['superior6564'],
    install_requires=['', ''],

    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ]
)
